CvlrInvarSpec

Struct CvlrInvarSpec 

pub struct CvlrInvarSpec<A, B>(/* private fields */);
A specification for invariants that must hold before and after operations.

This type represents a specification where:

  • An assumption (additional precondition) is assumed before the operation
  • An invariant must hold both before and after the operation

The invariant is assumed in the pre-state and asserted in the post-state.

Implementations

Source

impl<A, B> CvlrInvarSpec<A, B>

pub fn invariant(&self) -> &B

Returns a reference to the invariant expression.

pub fn assumption(&self) -> &A

Returns a reference to the assumption expression.